AccessRule class

An access control rule.

Constructors

AccessRule({required String boxName, String? keyPattern, required String role, required Set<Permission> permissions, bool deny = false})
Creates an AccessRule.
const

Properties

boxName String
The box name this rule applies to (empty for all boxes).
final
deny bool
Whether this is a deny rule (overrides grants).
final
hashCode int
The hash code for this object.
no setterinherited
keyPattern String?
The key pattern this rule applies to (null for all keys).
final
permissions Set<Permission>
The permissions granted by this rule.
final
role String
The role this rule applies to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String boxName, dynamic key) bool
Whether this rule matches the given boxName and key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited