CostEstimate class

Cost estimation for a query execution plan.

Constructors

CostEstimate({required double rowsScanned, required double rowsReturned, required double cpuCost, required double ioCost})
Creates a CostEstimate.
const

Properties

cpuCost double
Estimated CPU cost (relative units).
final
hashCode int
The hash code for this object.
no setterinherited
ioCost double
Estimated I/O cost (relative units).
final
rowsReturned double
Estimated number of rows returned.
final
rowsScanned double
Estimated number of rows scanned.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCost double
Total estimated cost.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited