GeoQuery class

Geospatial query support for Rift. Allows searching by geographic proximity and bounding boxes.

Constructors

GeoQuery()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

boundingBoxFromRadius(GeoPoint center, double radiusMeters) GeoBoundingBox
Calculate the bounding box that contains all points within radiusMeters of center. Useful for pre-filtering before applying Haversine distance.
countWithinRadius(Box box, String latField, String lonField, GeoPoint center, double radiusMeters) int
Count points within a radius from a center point.
findInBoundingBox(Box box, String latField, String lonField, GeoBoundingBox bbox) List<GeoResult>
Find all points within a bounding box.
findNearest(Box box, String latField, String lonField, GeoPoint center, {int k = 10}) List<GeoResult>
Find k nearest neighbors to a center point.
findWithinRadius(Box box, String latField, String lonField, GeoPoint center, double radiusMeters) List<GeoResult>
Find all points within a radius (in meters) from a center point.
haversineDistance(GeoPoint a, GeoPoint b) double
Calculate distance between two points using Haversine formula. Returns the distance in meters.
isPointInBoundingBox(GeoPoint point, GeoBoundingBox bbox) bool
Check if a point is inside a bounding box.