IndexHint class

Suggestion for an index that would improve query performance.

Constructors

IndexHint({required List<String> fields, required String indexType, required double improvementFactor, required String reason})
Creates an IndexHint.
const

Properties

fields List<String>
The field(s) to index.
final
hashCode int
The hash code for this object.
no setterinherited
improvementFactor double
The estimated improvement factor (e.g., 10.0 means 10x faster).
final
indexType String
The type of index recommended.
final
reason String
Reason for the suggestion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited