PooledBox<E> class

A boxed reference obtained from the pool.

Constructors

PooledBox({required Box<E> box, required DateTime acquiredAt, required DateTime createdAt})
Creates a PooledBox.

Properties

acquiredAt DateTime
When this pooled connection was acquired.
final
age Duration
The age of this connection.
no setter
box Box<E>
The underlying box instance.
final
createdAt DateTime
When the connection was created.
final
hashCode int
The hash code for this object.
no setterinherited
inUseDuration Duration
The duration this connection has been in use.
no setter
isReleased bool
Whether this pooled connection has been released.
no setter
name String
The name of the box.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited