RateLimitExceeded class

Exception thrown when rate limit is exceeded.

Implemented types

Constructors

RateLimitExceeded({required RateLimitPolicy policy, String? boxName, required Duration retryAfter})
Creates a RateLimitExceeded.
const

Properties

boxName String?
The box name, if applicable.
final
hashCode int
The hash code for this object.
no setterinherited
policy RateLimitPolicy
The policy that was exceeded.
final
retryAfter Duration
The time until the next token is available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited