RiftOperation class

Represents a Rift database operation.

Constructors

RiftOperation({required String boxName, required String type, String? key, dynamic value, Map<String, dynamic> metadata = const {}, DateTime? timestamp})
Create a Rift operation.

Properties

boxName String
The name of the box this operation targets.
final
hashCode int
The hash code for this object.
no setterinherited
key String?
The key involved in the operation (null for box-level operations).
final
metadata Map<String, dynamic>
Additional metadata about the operation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When this operation occurred.
final
type String
The type of operation ('put', 'get', 'delete', 'clear', 'query', etc.).
final
value → dynamic
The value involved in the operation (null for reads and deletes).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited