RiftPluginContext class

Context provided to a plugin when it is registered.

Constructors

RiftPluginContext(Map<String, dynamic> config)
Create a plugin context.

Properties

config Map<String, dynamic>
Plugin-specific configuration.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, dynamic>
Plugin-specific state (persists across operations).
final

Methods

getConfig<T>(String key) → T?
Get a config value.
getState<T>(String key) → T?
Get a state value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(String key, dynamic value) → void
Set a state value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited