AdaptiveCacheStats class
Statistics about cache performance.
Constructors
- AdaptiveCacheStats({required int lookups, required int hits, required int misses, required int evictions, required int size, required int maxSize, required AdaptiveCacheStrategy strategy})
-
Creates an AdaptiveCacheStats.
const
Properties
- evictions → int
-
Number of cache evictions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitRate → double
-
The hit rate (0.0 to 1.0).
no setter
- hits → int
-
Number of cache hits.
final
- lookups → int
-
Total number of cache lookups.
final
- maxSize → int
-
Maximum cache size.
final
- misses → int
-
Number of cache misses.
final
- missRate → double
-
The miss rate (0.0 to 1.0).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Current cache size.
final
- strategy → AdaptiveCacheStrategy
-
The current strategy being used.
final
- utilization → double
-
The utilization ratio (0.0 to 1.0).
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited