AuditEntry class
A single audit log entry.
Constructors
- AuditEntry({required int id, required DateTime timestamp, required AuditAction action, required String boxName, String? key, dynamic oldValue, dynamic newValue})
- Create an audit entry.
Properties
- action → AuditAction
-
The action that was performed.
final
- boxName → String
-
The name of the box.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Auto-incrementing entry ID.
final
- key → String?
-
The key that was affected.
final
- newValue → dynamic
-
The value after the action.
final
- oldValue → dynamic
-
The value before the action.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When this entry was recorded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited