AuditLog class
Event log and audit trail for Rift. Records all modifications with timestamps for compliance and debugging.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the audit log is empty.
no setter
- length → int
-
Number of entries in the audit log.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AuditEntry> -
Stream of audit entries (real-time).
no setter
Methods
-
clear(
) → void - Clear the audit log.
-
dispose(
) → void - Dispose the audit log.
-
exportJson(
) → List< Map< String, dynamic> > - Export audit log as JSON-serializable list.
-
exportJsonForBox(
String boxName) → List< Map< String, dynamic> > - Export audit log filtered by box name.
-
getEntries(
{String? boxName, AuditAction? action, DateTime? since, DateTime? until}) → List< AuditEntry> - Get all entries, optionally filtered.
-
getEntriesForKey(
String boxName, String key) → List< AuditEntry> - Get entries for a specific key.
-
getLatest(
{String? boxName, AuditAction? action}) → AuditEntry? - Get the latest entry, optionally filtered.
-
log(
AuditAction action, String boxName, {String? key, dynamic oldValue, dynamic newValue}) → void - Log an operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited