CompactionEvent class
Event emitted when a box is compacted.
Constructors
- CompactionEvent(String boxName, Duration duration, DateTime timestamp)
- Create a CompactionEvent.
Properties
- boxName → String
-
The name of the box that was compacted.
final
- duration → Duration
-
How long the compaction took.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the compaction occurred.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited