OperationType enum
The type of database operation being measured.
Values
- put → const OperationType
-
A put (create/update) operation.
- get → const OperationType
-
A get (read) operation.
- delete → const OperationType
-
A delete operation.
- query → const OperationType
-
A query operation.
- batch → const OperationType
-
A batch/bulk operation.
- compaction → const OperationType
-
A compaction operation.
- transaction → const OperationType
-
A transaction operation.
- sync → const OperationType
-
A sync operation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OperationType> - A constant List of the values in this enum, in order of their declaration.